## Schema

### Required

- `certificate_authority_arn` (String)
- `certificate_signing_request` (String) The certificate signing request (CSR) for the Certificate.
- `signing_algorithm` (String) The name of the algorithm that will be used to sign the Certificate.
- `validity` (Attributes) Validity for a certificate. (see [below for nested schema](#nestedatt--validity))

### Optional

- `api_passthrough` (Attributes) Structure that specifies fields to be overridden in a certificate at the time of issuance. These requires an API Passthrough template be used or they will be ignored. (see [below for nested schema](#nestedatt--api_passthrough))
- `template_arn` (String)
- `validity_not_before` (Attributes) Validity for a certificate. (see [below for nested schema](#nestedatt--validity_not_before))

### Read-Only

- `arn` (String)
- `certificate` (String) The issued certificate in base 64 PEM-encoded format.
- `id` (String) Uniquely identifies the resource.

<a id="nestedatt--validity"></a>
### Nested Schema for `validity`

Required:

- `type` (String)
- `value` (Number)


<a id="nestedatt--api_passthrough"></a>
### Nested Schema for `api_passthrough`

Optional:

- `extensions` (Attributes) Structure that contains X.500 extensions for a Certificate. (see [below for nested schema](#nestedatt--api_passthrough--extensions))
- `subject` (Attributes) Structure that contains X.500 distinguished name information. (see [below for nested schema](#nestedatt--api_passthrough--subject))

<a id="nestedatt--api_passthrough--extensions"></a>
### Nested Schema for `api_passthrough.extensions`

Optional:

- `certificate_policies` (Attributes List) (see [below for nested schema](#nestedatt--api_passthrough--extensions--certificate_policies))
- `extended_key_usage` (Attributes List) (see [below for nested schema](#nestedatt--api_passthrough--extensions--extended_key_usage))
- `key_usage` (Attributes) Structure that contains X.509 KeyUsage information. (see [below for nested schema](#nestedatt--api_passthrough--extensions--key_usage))
- `subject_alternative_names` (Attributes List) (see [below for nested schema](#nestedatt--api_passthrough--extensions--subject_alternative_names))

<a id="nestedatt--api_passthrough--extensions--certificate_policies"></a>
### Nested Schema for `api_passthrough.extensions.certificate_policies`

Required:

- `cert_policy_id` (String) String that contains X.509 ObjectIdentifier information.

Optional:

- `policy_qualifiers` (Attributes List) (see [below for nested schema](#nestedatt--api_passthrough--extensions--certificate_policies--policy_qualifiers))

<a id="nestedatt--api_passthrough--extensions--certificate_policies--policy_qualifiers"></a>
### Nested Schema for `api_passthrough.extensions.certificate_policies.policy_qualifiers`

Required:

- `policy_qualifier_id` (String)
- `qualifier` (Attributes) Structure that contains a X.509 policy qualifier. (see [below for nested schema](#nestedatt--api_passthrough--extensions--certificate_policies--policy_qualifiers--qualifier))

<a id="nestedatt--api_passthrough--extensions--certificate_policies--policy_qualifiers--qualifier"></a>
### Nested Schema for `api_passthrough.extensions.certificate_policies.policy_qualifiers.qualifier`

Required:

- `cps_uri` (String)




<a id="nestedatt--api_passthrough--extensions--extended_key_usage"></a>
### Nested Schema for `api_passthrough.extensions.extended_key_usage`

Optional:

- `extended_key_usage_object_identifier` (String) String that contains X.509 ObjectIdentifier information.
- `extended_key_usage_type` (String)


<a id="nestedatt--api_passthrough--extensions--key_usage"></a>
### Nested Schema for `api_passthrough.extensions.key_usage`

Optional:

- `crl_sign` (Boolean)
- `data_encipherment` (Boolean)
- `decipher_only` (Boolean)
- `digital_signature` (Boolean)
- `encipher_only` (Boolean)
- `key_agreement` (Boolean)
- `key_cert_sign` (Boolean)
- `key_encipherment` (Boolean)
- `non_repudiation` (Boolean)


<a id="nestedatt--api_passthrough--extensions--subject_alternative_names"></a>
### Nested Schema for `api_passthrough.extensions.subject_alternative_names`

Optional:

- `directory_name` (Attributes) Structure that contains X.500 distinguished name information. (see [below for nested schema](#nestedatt--api_passthrough--extensions--subject_alternative_names--directory_name))
- `dns_name` (String) String that contains X.509 DnsName information.
- `edi_party_name` (Attributes) Structure that contains X.509 EdiPartyName information. (see [below for nested schema](#nestedatt--api_passthrough--extensions--subject_alternative_names--edi_party_name))
- `ip_address` (String) String that contains X.509 IpAddress information.
- `other_name` (Attributes) Structure that contains X.509 OtherName information. (see [below for nested schema](#nestedatt--api_passthrough--extensions--subject_alternative_names--other_name))
- `registered_id` (String) String that contains X.509 ObjectIdentifier information.
- `rfc_822_name` (String) String that contains X.509 Rfc822Name information.
- `uniform_resource_identifier` (String) String that contains X.509 UniformResourceIdentifier information.

<a id="nestedatt--api_passthrough--extensions--subject_alternative_names--directory_name"></a>
### Nested Schema for `api_passthrough.extensions.subject_alternative_names.uniform_resource_identifier`

Optional:

- `common_name` (String)
- `country` (String)
- `distinguished_name_qualifier` (String)
- `generation_qualifier` (String)
- `given_name` (String)
- `initials` (String)
- `locality` (String)
- `organization` (String)
- `organizational_unit` (String)
- `pseudonym` (String)
- `serial_number` (String)
- `state` (String)
- `surname` (String)
- `title` (String)


<a id="nestedatt--api_passthrough--extensions--subject_alternative_names--edi_party_name"></a>
### Nested Schema for `api_passthrough.extensions.subject_alternative_names.uniform_resource_identifier`

Required:

- `name_assigner` (String)
- `party_name` (String)


<a id="nestedatt--api_passthrough--extensions--subject_alternative_names--other_name"></a>
### Nested Schema for `api_passthrough.extensions.subject_alternative_names.uniform_resource_identifier`

Required:

- `type_id` (String) String that contains X.509 ObjectIdentifier information.
- `value` (String)




<a id="nestedatt--api_passthrough--subject"></a>
### Nested Schema for `api_passthrough.subject`

Optional:

- `common_name` (String)
- `country` (String)
- `distinguished_name_qualifier` (String)
- `generation_qualifier` (String)
- `given_name` (String)
- `initials` (String)
- `locality` (String)
- `organization` (String)
- `organizational_unit` (String)
- `pseudonym` (String)
- `serial_number` (String)
- `state` (String)
- `surname` (String)
- `title` (String)



<a id="nestedatt--validity_not_before"></a>
### Nested Schema for `validity_not_before`

Required:

- `type` (String)
- `value` (Number)

